==> icons-react-0.0.4.tgz: package/src/index.ts <==
import { Add } from "./Add";
import { AddPrivate } from "./AddPrivate";
import { AddPrivate2 } from "./AddPrivate2";
import { AddWindow } from "./AddWindow";
import { All } from "./All";
import { AppearanceFilled } from "./AppearanceFilled";
import { Audio } from "./Audio";
import { AudioNone } from "./AudioNone";
import { Avatar } from "./Avatar";
import { AvatarFilled } from "./AvatarFilled";
import { Back } from "./Back";
import { Biscuit } from "./Biscuit";
import { Block } from "./Block";
import { Bold } from "./Bold";
import { BulletList } from "./BulletList";
import { Cake } from "./Cake";
import { Calculator } from "./Calculator";
import { Calculator2 } from "./Calculator2";
import { Calendar } from "./Calendar";
import { Camera } from "./Camera";
import { Certificate } from "./Certificate";
import { Check } from "./Check";
import { ChevonRight12 } from "./ChevonRight12";
import { ChevronDown } from "./ChevronDown";
import { ChevronDown12 } from "./ChevronDown12";
import { ChevronLeft } from "./ChevronLeft";
import { ChevronLeft12 } from "./ChevronLeft12";
import { ChevronRight } from "./ChevronRight";
import { ChevronUp } from "./ChevronUp";
import { ChevronUp12 } from "./ChevronUp12";
import { Clock } from "./Clock";
import { Close } from "./Close";
import { CloseTabs } from "./CloseTabs";
import { CloseTabsToLeft } from "./CloseTabsToLeft";
import { CloseTabsToRight } from "./CloseTabsToRight";
import { Colour } from "./Colour";
import { CompassFilled } from "./CompassFilled";
import { Copy } from "./Copy";
import { Cube } from "./Cube";
import { Cut } from "./Cut";
import { Desktop } from "./Desktop";
import { Document } from "./Document";
import { Download } from "./Download";
import { Duplicate } from "./Duplicate";
import { ExitFullscreen } from "./ExitFullscreen";
import { ExtensionFilled } from "./ExtensionFilled";
import { Eye } from "./Eye";
import { Folder } from "./Folder";
import { Forward } from "./Forward";
import { Fullscreen } from "./Fullscreen";
import { Gesture } from "./Gesture";
import { Globe } from "./Globe";
import { Grid } from "./Grid";
import { GridAlt } from "./GridAlt";
import { Help } from "./Help";
import { Home } from "./Home";
import { HomeFilled } from "./HomeFilled";
import { Inbox } from "./Inbox";
import { Info } from "./Info";
import { InfoFilled } from "./InfoFilled";
import { Inspect } from "./Inspect";
import { Italic } from "./Italic";
import { Javascript } from "./Javascript";
import { KeyFilled } from "./KeyFilled";
import { LabBottle } from "./LabBottle";
import { Language } from "./Language";
import { Loading } from "./Loading";
import { LoadingBlack } from "./LoadingBlack";
import { Location } from "./Location";
import { Mail } from "./Mail";
import { MailFilled } from "./MailFilled";
import { Media } from "./Media";
import { Menu } from "./Menu";
import { Message } from "./Message";
import { MoreHorizontal } from "./MoreHorizontal";
import { MoreVertical } from "./MoreVertical";
import { NewBookmark } from "./NewBookmark";
import { NewFolder } from "./NewFolder";
import { NewNote } from "./NewNote";
import { News } from "./News";
import { Night } from "./Night";
import { Notepad } from "./Notepad";
import { NumberList } from "./NumberList";
import { OpenFolder } from "./OpenFolder";
import { OpenInNew } from "./OpenInNew";
import { Paste } from "./Paste";
import { Pause } from "./Pause";
import { Pdf } from "./Pdf";
import { Permission } from "./Permission";
import { Phone } from "./Phone";
import { Photo } from "./Photo";
import { Pip } from "./Pip";
import { Play } from "./Play";
import { PlayFilled } from "./PlayFilled";
import { Print } from "./Print";
import { PrintFilled } from "./PrintFilled";
import { Processes } from "./Processes";
import { Qrcode } from "./Qrcode";
import { Redo } from "./Redo";
import { Refresh } from "./Refresh";
import { Rss } from "./Rss";
import { Save } from "./Save";
import { Screenshot } from "./Screenshot";
import { Search } from "./Search";
import { SearchSidebar } from "./SearchSidebar";
import { Secure } from "./Secure";
import { SecureFilled } from "./SecureFilled";
import { Settings } from "./Settings";
import { SettingsFilled } from "./SettingsFilled";
import { ShoppingBag } from "./ShoppingBag";
import { SidebarsLeft } from "./SidebarsLeft";
import { SidebarsRight } from "./SidebarsRight";
import { Star } from "./Star";
import { StarFilled } from "./StarFilled";
import { StarFilled12 } from "./StarFilled12";
import { StarInTray } from "./StarInTray";
import { Stocks } from "./Stocks";
import { Stop } from "./Stop";
import { Stopwatch } from "./Stopwatch";
import { Strikethrough } from "./Strikethrough";
import { Subtitles } from "./Subtitles";
import { Sun } from "./Sun";
import { Swap } from "./Swap";
import { Sync } from "./Sync";
import { Tablet } from "./Tablet";
import { Tag } from "./Tag";
import { TagAlt } from "./TagAlt";
import { Title1 } from "./Title1";
import { Title2 } from "./Title2";
import { Title3 } from "./Title3";
import { Trash } from "./Trash";
import { Tv } from "./Tv";
import { Underline } from "./Underline";
import { Undo } from "./Undo";
import { UnsecureFilled } from "./UnsecureFilled";
import { UnsecureWarningFilled } from "./UnsecureWarningFilled";
import { UpdateFilled } from "./UpdateFilled";
import { Upload } from "./Upload";
import { Usb } from "./Usb";
import { User } from "./User";
import { UserFilled } from "./UserFilled";
import { Video } from "./Video";
import { VideoCamera } from "./VideoCamera";
import { WarningFilled } from "./WarningFilled";
import { Weather } from "./Weather";
import { WeatherFilled } from "./WeatherFilled";
import { WeatherFilledQuestion } from "./WeatherFilledQuestion";
import { ZoomIn } from "./ZoomIn";
import { ZoomOut } from "./ZoomOut";

export default {
	Home,
	Back,
	Forward,
	Refresh,
	Secure,
	Search,
	Star,
	Add,
	Close,
	Avatar,
	Document,
	Info,
	Print,
	Check,
	Inspect,
	Save,
	Download,
	Sync,
	Language,
	OpenInNew,
	Gesture,
	Grid,
	Globe,
	ShoppingBag,
	ChevronLeft,
	ChevronRight,
	ChevronDown,
	ChevronUp,
	Menu,
	StarInTray,
	Desktop,
	Tablet,
	Phone,
	Tv,
	Copy,
	Cut,
	Paste,
	Folder,
	Qrcode,
	GridAlt,
	Certificate,
	Biscuit,
	Permission,
	Location,
	NewFolder,
	OpenFolder,
	Trash,
	Notepad,
	NewNote,
	Bold,
	Italic,
	Underline,
	Strikethrough,
	BulletList,
	NumberList,
	Title1,
	Title2,
	Title3,
	Calculator,
	Tag,
	Clock,
	NewBookmark,
	All,
	Pdf,
	Javascript,
	Sun,
	Night,
	User,
	Mail,
	Colour,
	MoreHorizontal,
	TagAlt,
	Processes,
	Rss,
	Media,
	Stocks,
	Weather,
	Cube,
	News,
	SearchSidebar,
	SidebarsLeft,
	SidebarsRight,
	Play,
	Pause,
	Subtitles,
	Audio,
	AudioNone,
	Fullscreen,
	ExitFullscreen,
	Pip,
	Calculator2,
	Duplicate,
	CloseTabsToRight,
	CloseTabs,
	CloseTabsToLeft,
	Photo,
	Video,
	AddWindow,
	AddPrivate,
	AddPrivate2,
	Help,
	Screenshot,
	Undo,
	Redo,
	Block,
	Eye,
	Message,
	Loading,
	LoadingBlack,
	ZoomIn,
	ZoomOut,
	Usb,
	Swap,
	Stop,
	Stopwatch,
	Settings,
	Inbox,
	VideoCamera,
	Calendar,
	Cake,
	Camera,
	Upload,
	LabBottle,
	MoreVertical,
	MailFilled,
	PlayFilled,
	WeatherFilled,
	WeatherFilledQuestion,
	StarFilled,
	PrintFilled,
	AppearanceFilled,
	AvatarFilled,
	CompassFilled,
	HomeFilled,
	SecureFilled,
	UnsecureFilled,
	UnsecureWarningFilled,
	WarningFilled,
	InfoFilled,
	KeyFilled,
	UpdateFilled,
	ExtensionFilled,
	SettingsFilled,
	UserFilled,
	StarFilled12,
	ChevronLeft12,
	ChevronUp12,
	ChevonRight12,
	ChevronDown12,
};

==> icons-react-0.0.9.tgz: package/src/index.ts <==
import { Accessibility } from "./Accessibility";
import { Add } from "./Add";
import { AddPrivate } from "./AddPrivate";
import { AddPrivate2 } from "./AddPrivate2";
import { AddWindow } from "./AddWindow";
import { All } from "./All";
import { Anchor } from "./Anchor";
import { AppearanceFilled } from "./AppearanceFilled";
import { Audio } from "./Audio";
import { AudioNone } from "./AudioNone";
import { Avatar } from "./Avatar";
import { AvatarFilled } from "./AvatarFilled";
import { Back } from "./Back";
import { Bell } from "./Bell";
import { Biscuit } from "./Biscuit";
import { Block } from "./Block";
import { BlockFilled } from "./BlockFilled";
import { Bold } from "./Bold";
import { Building } from "./Building";
import { BulletList } from "./BulletList";
import { Cake } from "./Cake";
import { CakeFilled } from "./CakeFilled";
import { Calculator } from "./Calculator";
import { Calculator2 } from "./Calculator2";
import { Calendar } from "./Calendar";
import { CalendarMonths } from "./CalendarMonths";
import { Camera } from "./Camera";
import { CameraFilled } from "./CameraFilled";
import { Car } from "./Car";
import { Certificate } from "./Certificate";
import { Check } from "./Check";
import { ChevonRight12 } from "./ChevonRight12";
import { ChevronDown } from "./ChevronDown";
import { ChevronDown12 } from "./ChevronDown12";
import { ChevronLeft } from "./ChevronLeft";
import { ChevronLeft12 } from "./ChevronLeft12";
import { ChevronRight } from "./ChevronRight";
import { ChevronUp } from "./ChevronUp";
import { ChevronUp12 } from "./ChevronUp12";
import { Clock } from "./Clock";
import { ClockFilled } from "./ClockFilled";
import { Close } from "./Close";
import { CloseTabs } from "./CloseTabs";
import { CloseTabsToLeft } from "./CloseTabsToLeft";
import { CloseTabsToRight } from "./CloseTabsToRight";
import { Colour } from "./Colour";
import { CompassFilled } from "./CompassFilled";
import { Copy } from "./Copy";
import { Cube } from "./Cube";
import { CubeFilled } from "./CubeFilled";
import { Cut } from "./Cut";
import { Desktop } from "./Desktop";
import { Document } from "./Document";
import { Download } from "./Download";
import { DuplicateWindow } from "./DuplicateWindow";
import { ExitFullscreen } from "./ExitFullscreen";
import { ExtensionFilled } from "./ExtensionFilled";
import { Eye } from "./Eye";
import { EyeFilled } from "./EyeFilled";
import { Folder } from "./Folder";
import { Forward } from "./Forward";
import { Fullscreen } from "./Fullscreen";
import { Gesture } from "./Gesture";
import { Globe } from "./Globe";
import { Gps } from "./Gps";
import { Grid } from "./Grid";
import { GridAlt } from "./GridAlt";
import { Help } from "./Help";
import { HelpFilled } from "./HelpFilled";
import { Home } from "./Home";
import { HomeFilled } from "./HomeFilled";
import { Inbox } from "./Inbox";
import { Info } from "./Info";
import { InfoFilled } from "./InfoFilled";
import { Inspect } from "./Inspect";
import { Italic } from "./Italic";
import { Javascript } from "./Javascript";
import { KeyFilled } from "./KeyFilled";
import { LabBottle } from "./LabBottle";
import { Language } from "./Language";
import { Lightbulb } from "./Lightbulb";
import { Loading } from "./Loading";
import { LoadingBlack } from "./LoadingBlack";
import { Location } from "./Location";
import { LocationFilled } from "./LocationFilled";
import { Mail } from "./Mail";
import { MailFilled } from "./MailFilled";
import { Media } from "./Media";
import { Menu } from "./Menu";
import { Message } from "./Message";
import { Microphone } from "./Microphone";
import { MoreHorizontal } from "./MoreHorizontal";
import { Network } from "./Network";
import { NewBookmark } from "./NewBookmark";
import { NewNote } from "./NewNote";
import { News } from "./News";
import { NewsFilled } from "./NewsFilled";
import { Night } from "./Night";
import { Notepad } from "./Notepad";
import { OpenInNew } from "./OpenInNew";
import { PaintBrush } from "./PaintBrush";
import { Paste } from "./Paste";
import { Pause } from "./Pause";
import { Pdf } from "./Pdf";
import { Permission } from "./Permission";
import { Phone } from "./Phone";
import { PhoneHorizontal } from "./PhoneHorizontal";
import { Photo } from "./Photo";
import { PhotoFilled } from "./PhotoFilled";
import { Pip } from "./Pip";
import { Play } from "./Play";
import { PlayFilled } from "./PlayFilled";
import { Print } from "./Print";
import { PrintFilled } from "./PrintFilled";
import { Processes } from "./Processes";
import { ProcessesFilled } from "./ProcessesFilled";
import { Qrcode } from "./Qrcode";
import { Redo } from "./Redo";
import { Refresh } from "./Refresh";
import { Robot } from "./Robot";
import { Rss } from "./Rss";
import { RssFilled } from "./RssFilled";
import { Save } from "./Save";
import { Screenshot } from "./Screenshot";
import { Search } from "./Search";
import { SearchSidebar } from "./SearchSidebar";
import { Secure } from "./Secure";
import { SecureFilled } from "./SecureFilled";
import { Send } from "./Send";
import { SendFilled } from "./SendFilled";
import { Settings } from "./Settings";
import { SettingsFilled } from "./SettingsFilled";
import { Share } from "./Share";
import { ShoppingBag } from "./ShoppingBag";
import { SidebarsLeft } from "./SidebarsLeft";
import { SidebarsLeftFilled } from "./SidebarsLeftFilled";
import { SidebarsRight } from "./SidebarsRight";
import { SidebarsRightFilled } from "./SidebarsRightFilled";
import { Star } from "./Star";
import { StarFilled } from "./StarFilled";
import { StarFilled12 } from "./StarFilled12";
import { StarInTray } from "./StarInTray";
import { Stocks } from "./Stocks";
import { StocksFilld } from "./StocksFilld";
import { Stop } from "./Stop";
import { Stopwatch } from "./Stopwatch";
import { Strikethrough } from "./Strikethrough";
import { Subtitles } from "./Subtitles";
import { SubtitlesFilled } from "./SubtitlesFilled";
import { Sun } from "./Sun";
import { Swap } from "./Swap";
import { Sync } from "./Sync";
import { Tag } from "./Tag";
import { TagAlt } from "./TagAlt";
import { TagAltFilled } from "./TagAltFilled";
import { TagFilled } from "./TagFilled";
import { Terminal } from "./Terminal";
import { Train } from "./Train";
import { Trash } from "./Trash";
import { Tv } from "./Tv";
import { Underline } from "./Underline";
import { Undo } from "./Undo";
import { UnsecureFilled } from "./UnsecureFilled";
import { UnsecureWarningFilled } from "./UnsecureWarningFilled";
import { UpdateFilled } from "./UpdateFilled";
import { Upload } from "./Upload";
import { Usb } from "./Usb";
import { User } from "./User";
import { UserFilled } from "./UserFilled";
import { Video } from "./Video";
import { VideoCamera } from "./VideoCamera";
import { VideoCameraFilled } from "./VideoCameraFilled";
import { VideoFilled } from "./VideoFilled";
import { WarningFilled } from "./WarningFilled";
import { Waveform } from "./Waveform";
import { Weather } from "./Weather";
import { WeatherFilled } from "./WeatherFilled";
import { WeatherFilledQuestion } from "./WeatherFilledQuestion";
import { WifiDisconnected } from "./WifiDisconnected";
import { WifiFull } from "./WifiFull";
import { WifiIssues1 } from "./WifiIssues1";
import { WifiIssues2 } from "./WifiIssues2";
import { WifiIssues3 } from "./WifiIssues3";
import { ZoomIn } from "./ZoomIn";
import { ZoomOut } from "./ZoomOut";

export default {
	Home,
	Back,
	Forward,
	Refresh,
	Secure,
	Search,
	Star,
	Add,
	Close,
	Avatar,
	Document,
	Print,
	Check,
	Inspect,
	Save,
	Download,
	Sync,
	Language,
	OpenInNew,
	Gesture,
	Grid,
	Globe,
	Mail,
	ShoppingBag,
	ChevronLeft,
	ChevronRight,
	ChevronDown,
	ChevronUp,
	Menu,
	StarInTray,
	Desktop,
	PhoneHorizontal,
	Phone,
	Tv,
	Copy,
	Cut,
	Paste,
	DuplicateWindow,
	Folder,
	Qrcode,
	GridAlt,
	Certificate,
	Biscuit,
	Permission,
	Location,
	Usb,
	Trash,
	Notepad,
	NewNote,
	Bold,
	Italic,
	Underline,
	Strikethrough,
	BulletList,
	Calculator,
	Tag,
	Clock,
	NewBookmark,
	All,
	Pdf,
	Javascript,
	Sun,
	Night,
	User,
	Swap,
	Calculator2,
	Colour,
	MoreHorizontal,
	Stopwatch,
	TagAlt,
	Processes,
	Rss,
	Media,
	Stocks,
	Weather,
	Cube,
	News,
	SearchSidebar,
	SidebarsLeft,
	SidebarsRight,
	Play,
	Pause,
	Stop,
	Subtitles,
	Audio,
	AudioNone,
	Fullscreen,
	ExitFullscreen,
	Pip,
	CloseTabsToRight,
	CloseTabs,
	CloseTabsToLeft,
	Photo,
	Video,
	AddWindow,
	AddPrivate,
	AddPrivate2,
	Help,
	Info,
	Screenshot,
	Undo,
	Redo,
	Block,
	Eye,
	Message,
	Loading,
	LoadingBlack,
	ZoomIn,
	ZoomOut,
	Settings,
	Inbox,
	VideoCamera,
	Cake,
	Camera,
	Upload,
	LabBottle,
	Send,
	Building,
	Calendar,
	CalendarMonths,
	Gps,
	Robot,
	Waveform,
	Lightbulb,
	Terminal,
	Share,
	Microphone,
	WifiFull,
	WifiIssues1,
	WifiIssues2,
	WifiIssues3,
	WifiDisconnected,
	Anchor,
	Car,
	Train,
	Accessibility,
	PaintBrush,
	Bell,
	Network,
	MailFilled,
	PlayFilled,
	WeatherFilled,
	WeatherFilledQuestion,
	StarFilled,
	PrintFilled,
	AppearanceFilled,
	AvatarFilled,
	CompassFilled,
	HomeFilled,
	SecureFilled,
	UnsecureFilled,
	UnsecureWarningFilled,
	WarningFilled,
	InfoFilled,
	HelpFilled,
	KeyFilled,
	UpdateFilled,
	ExtensionFilled,
	SettingsFilled,
	UserFilled,
	SendFilled,
	LocationFilled,
	PhotoFilled,
	VideoFilled,
	SubtitlesFilled,
	TagFilled,
	TagAltFilled,
	ClockFilled,
	BlockFilled,
	ProcessesFilled,
	RssFilled,
	StocksFilld,
	CubeFilled,
	NewsFilled,
	SidebarsLeftFilled,
	SidebarsRightFilled,
	EyeFilled,
	VideoCameraFilled,
	CakeFilled,
	CameraFilled,
	StarFilled12,
	ChevronLeft12,
	ChevronUp12,
	ChevonRight12,
	ChevronDown12,
};
